==> dkist_processing_common-10.6.1rc1.tar.gz: dkist_processing_common-10.6.1rc1/dkist_processing_common/models/graphql.py <==
"""GraphQL Data models for the metadata store api."""
from pydantic import BaseModel
from pydantic import Json


class RecipeRunMutation(BaseModel):
    """Recipe run mutation record."""

    recipeRunId: int
    recipeRunStatusId: int


class RecipeRunStatusQuery(BaseModel):
    """Recipe run status query for the recipeRunStatuses endpoint."""

    recipeRunStatusName: str


class RecipeRunStatusMutation(BaseModel):
    """Recipe run status mutation record."""

    recipeRunStatusName: str
    isComplete: bool
    recipeRunStatusDescription: str


class RecipeRunStatusResponse(BaseModel):
    """Response to a recipe run status query."""

    recipeRunStatusId: int


class InputDatasetPartTypeResponse(BaseModel):
    """Response class for the input dataset part type entity."""

    inputDatasetPartTypeName: str


class InputDatasetPartResponse(BaseModel):
    """Response class for the input dataset part entity."""

    inputDatasetPartId: int
    inputDatasetPartDocument: Json[list[dict]]
    inputDatasetPartType: InputDatasetPartTypeResponse


class InputDatasetInputDatasetPartResponse(BaseModel):
    """Response class for the join entity between input datasets and input dataset parts."""

    inputDatasetPart: InputDatasetPartResponse


class InputDatasetResponse(BaseModel):
    """Input dataset query response."""

    inputDatasetId: int
    isActive: bool
    inputDatasetInputDatasetParts: list[InputDatasetInputDatasetPartResponse]


class InputDatasetRecipeInstanceResponse(BaseModel):
    """Recipe instance query response."""

    inputDataset: InputDatasetResponse


class InputDatasetRecipeRunResponse(BaseModel):
    """Recipe run query response."""

    recipeInstance: InputDatasetRecipeInstanceResponse


class RecipeInstanceResponse(BaseModel):
    """Recipe instance query response."""

    recipeId: int
    inputDatasetId: int


class RecipeRunProvenanceResponse(BaseModel):
    """Response for the metadata store recipeRunProvenances and mutations endpoints."""

    recipeRunProvenanceId: int
    isTaskManual: bool


class RecipeRunResponse(BaseModel):
    """Recipe run query response."""

    recipeInstance: RecipeInstanceResponse
    recipeInstanceId: int
    recipeRunProvenances: list[RecipeRunProvenanceResponse]
    configuration: Json[dict] | None = {}


class RecipeRunMutationResponse(BaseModel):
    """Recipe run mutation response."""

    recipeRunId: int


class RecipeRunQuery(BaseModel):
    """Query parameters for the metadata store endpoint recipeRuns."""

    recipeRunId: int


class DatasetCatalogReceiptAccountMutation(BaseModel):
    """
    Dataset catalog receipt account mutation record.

    It sets an expected object count for a dataset so that dataset inventory creation
    doesn't happen until all objects are transferred and inventoried.
    """

    datasetId: str
    expectedObjectCount: int


class DatasetCatalogReceiptAccountResponse(BaseModel):
    """Dataset catalog receipt account response for query and mutation endpoints."""

    datasetCatalogReceiptAccountId: int


class RecipeRunProvenanceMutation(BaseModel):
    """Recipe run provenance mutation record."""

    inputDatasetId: int
    isTaskManual: bool
    recipeRunId: int
    taskName: str
    libraryVersions: str
    workflowVersion: str
    codeVersion: str = None


class QualityCreation(BaseModel):
    """Quality data creation record."""

    datasetId: str
    metricCode: str
    facet: str | None = None
    name: str | None = None
    description: str | None = None
    statement: str | None = None
    # JSON array
    warnings: str | None = None
    # JSON objects
    plotData: str | None = None
    tableData: str | None = None
    histogramData: str | None = None
    modmatData: str | None = None
    raincloudData: str | None = None
    efficiencyData: str | None = None


class QualitiesRequest(BaseModel):
    """Query parameters for quality data."""

    datasetId: str


class QualityResponse(BaseModel):
    """Query Response for quality data."""

    qualityId: int

==> dkist_processing_common-10.8.1.tar.gz: dkist_processing_common-10.8.1/dkist_processing_common/models/graphql.py <==
"""GraphQL Data models for the metadata store api."""
from pydantic import BaseModel
from pydantic import field_validator
from pydantic import Json


class RecipeRunMutation(BaseModel):
    """Recipe run mutation record."""

    recipeRunId: int
    recipeRunStatusId: int


class RecipeRunStatusQuery(BaseModel):
    """Recipe run status query for the recipeRunStatuses endpoint."""

    recipeRunStatusName: str


class RecipeRunStatusMutation(BaseModel):
    """Recipe run status mutation record."""

    recipeRunStatusName: str
    isComplete: bool
    recipeRunStatusDescription: str


class RecipeRunStatusResponse(BaseModel):
    """Response to a recipe run status query."""

    recipeRunStatusId: int


class InputDatasetPartTypeResponse(BaseModel):
    """Response class for the input dataset part type entity."""

    inputDatasetPartTypeName: str


class InputDatasetPartResponse(BaseModel):
    """Response class for the input dataset part entity."""

    inputDatasetPartId: int
    inputDatasetPartDocument: Json[list[dict]]
    inputDatasetPartType: InputDatasetPartTypeResponse


class InputDatasetInputDatasetPartResponse(BaseModel):
    """Response class for the join entity between input datasets and input dataset parts."""

    inputDatasetPart: InputDatasetPartResponse


class InputDatasetResponse(BaseModel):
    """Input dataset query response."""

    inputDatasetId: int
    isActive: bool
    inputDatasetInputDatasetParts: list[InputDatasetInputDatasetPartResponse]


class InputDatasetRecipeInstanceResponse(BaseModel):
    """Recipe instance query response."""

    inputDataset: InputDatasetResponse


class InputDatasetRecipeRunResponse(BaseModel):
    """Recipe run query response."""

    recipeInstance: InputDatasetRecipeInstanceResponse


class RecipeInstanceResponse(BaseModel):
    """Recipe instance query response."""

    recipeId: int
    inputDatasetId: int


class RecipeRunProvenanceResponse(BaseModel):
    """Response for the metadata store recipeRunProvenances and mutations endpoints."""

    recipeRunProvenanceId: int
    isTaskManual: bool


class RecipeRunConfiguration(BaseModel):
    """Response class for a recipe run configuration dictionary."""

    validate_l1_on_write: bool = True
    destination_bucket: str = "data"
    tile_size: int | None = None
    trial_directory_name: str | None = None
    trial_root_directory_name: str | None = None
    teardown_enabled: bool = True
    trial_exclusive_transfer_tag_lists: list[str] | None = None


class RecipeRunResponse(BaseModel):
    """Recipe run query response."""

    recipeInstance: RecipeInstanceResponse
    recipeInstanceId: int
    recipeRunProvenances: list[RecipeRunProvenanceResponse]
    configuration: Json[dict] | None

    @field_validator("configuration", mode="after")
    @classmethod
    def _use_recipe_run_configuration_model(cls, value):
        if value is None:
            return RecipeRunConfiguration()
        return RecipeRunConfiguration.model_validate(value)


class RecipeRunMutationResponse(BaseModel):
    """Recipe run mutation response."""

    recipeRunId: int


class RecipeRunQuery(BaseModel):
    """Query parameters for the metadata store endpoint recipeRuns."""

    recipeRunId: int


class DatasetCatalogReceiptAccountMutation(BaseModel):
    """
    Dataset catalog receipt account mutation record.

    It sets an expected object count for a dataset so that dataset inventory creation
    doesn't happen until all objects are transferred and inventoried.
    """

    datasetId: str
    expectedObjectCount: int


class DatasetCatalogReceiptAccountResponse(BaseModel):
    """Dataset catalog receipt account response for query and mutation endpoints."""

    datasetCatalogReceiptAccountId: int


class RecipeRunProvenanceMutation(BaseModel):
    """Recipe run provenance mutation record."""

    inputDatasetId: int
    isTaskManual: bool
    recipeRunId: int
    taskName: str
    libraryVersions: str
    workflowVersion: str
    codeVersion: str | None = None


class QualityCreation(BaseModel):
    """Quality data creation record."""

    datasetId: str
    metricCode: str
    facet: str | None = None
    name: str | None = None
    description: str | None = None
    statement: str | None = None
    # JSON array
    warnings: str | None = None
    # JSON objects
    plotData: str | None = None
    tableData: str | None = None
    histogramData: str | None = None
    modmatData: str | None = None
    raincloudData: str | None = None
    efficiencyData: str | None = None


class QualitiesRequest(BaseModel):
    """Query parameters for quality data."""

    datasetId: str


class QualityResponse(BaseModel):
    """Query Response for quality data."""

    qualityId: int
